Examples
--------

The following examples are derived directly from IPython notebooks in the
hgvs source code `examples directory
<https://bitbucket.org/invitae/hgvs/src/tip/examples/>`_.

.. toctree::
  :glob:

  examples/*
